Read from Pandas DataFrame
==========================

This example demonstrates how to integrate Pandas DataFrames with *libadalina-core* functionalities.
It shows how to:

1. Load Open Street Map data from a CSV files using Pandas functions
2. Load the Pandas DataFrame into Sedona
3. Create a buffer around the linestrings in the Open Street Map

.. toctree::

   /_collections/notebooks/read_pandas.ipynb
